@@ -19,12 +19,15 @@ test_that("diagram_ksvm detects incorrect parameters correctly",{
 
 test_that("diagram_ksvm can accept inputs from TDA, TDAstats and diagram_to_df",{
   
+  skip_on_cran()
+  
   D1 = TDA::ripsDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxscale = 1,maxdimension = 1)
   D2 = TDA::alphaComplexDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxdimension = 1)
   D3 = TDA::ripsDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxscale = 1,maxdimension = 1,library = "dionysus",location = T)
   D4 = TDAstats::calculate_homology(data.frame(x = runif(50,0,1),y = runif(50,0,1)),threshold = 1)
   expect_s3_class(diagram_ksvm(diagrams = list(D1,D2,D3,D4),y = c(1,2,3,4),num_workers = 2,dim = c(1)),"diagram_ksvm")
   expect_error(diagram_ksvm(diagrams = list(D1,D2,D3,D4),y = c(1,2,3,4),num_workers = 2,dim = c(0)),"Inf")
+  expect_error(diagram_ksvm(diagrams = list(D1,D2,D3,D4),y = c(1,2,3,4),num_workers = 2,cv = 2,dim = c(0)),"Inf")
   
 })
 
@@ -38,6 +41,7 @@ test_that("predict_diagram_ksvm detects incorrect parameters correctly",{
   expect_error(predict_diagram_ksvm(new_diagrams = NULL,ksvm,num_workers = 2),"NULL")
   expect_error(predict_diagram_ksvm(new_diagrams = list(D1,"1"),ksvm,num_workers = 2),"Diagrams")
   expect_error(predict_diagram_ksvm(new_diagrams = list(D1,D2,D3),model = list(1,2,3),num_workers = 2),"ksvm")
+  expect_error(predict_diagram_ksvm(new_diagrams = list(D1,D2,D3),model = NULL,num_workers = 2),"supplied")
   
 })
 
@@ -81,6 +85,8 @@ test_that("predict_diagram_ksvm is computing correctly",{
 
 test_that("diagram_ksvm can accept inputs from TDA, TDAstats and diagram_to_df",{
   
+  skip_on_cran()
+  
   D1 = TDA::ripsDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxscale = 1,maxdimension = 1)
   D2 = TDA::alphaComplexDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxdimension = 1)
   D3 = TDA::ripsDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxscale = 1,maxdimension = 1,library = "dionysus",location = T)
